-- ========================================================================== --
-- 										 EskaQuestTracker                                       --
-- @Author   : Skamer <https://mods.curse.com/members/DevSkamer>              --
-- @Website  : https://wow.curseforge.com/projects/eska-quest-tracker         --
-- ========================================================================== --
Scorpio                "EskaQuestTracker.Options"                        "1.0.1"
-- ========================================================================== --
namespace "EQT"                                                               --
import "System"                                                               --
-- ========================================================================== --
_AceGUI = LibStub("AceGUI-3.0")
_AceConfig = LibStub("AceConfig-3.0")
_AceConfigRegistry = LibStub("AceConfigRegistry-3.0")
_AceConfigDialog = LibStub("AceConfigDialog-3.0")
-- ========================[[ OptionBuilder ]]==================================
_OptionBuilder  = OptionBuilder()
-- =============================================================================
_Fonts          = _LibSharedMedia:List("font")
_TextTransforms = {
  ["none"] = "None",
  ["uppercase"] = "Upper case",
  ["lowercase"] = "Lower case",
}
-- ========================================================================== --
GetFontIndex = function(font)
  for i, v in next, _Fonts do
    if v == font then return i end
  end
end
-- ========================================================================== --
local f

local function FillSpace(str, maxCharacter)
  local charDiff = maxCharacter - str:len()
  local finalStr = str
  for i = 1, maxCharacter do
    if i > str:len() then
      finalStr = finalStr .. " "
    end
  end

  return finalStr
end

local function CreateRowString(label, field, strColorLabel, strColorField, maxChar)
  local finalStr = ""

  label = FillSpace(label, maxChar or 12)
  if strColorLabel then
    label = string.format("|cff%s%s|r", strColorLabel, label)
  end

  if strColorField then
    field = string.format("|cff%s%s|r", strColorField, field)
  end

  finalStr = label.. " ".. field

  return finalStr
end

_Settings = {
  type = "group",
  name = "Eska Quest tracker - Options",
  args = {
    EQT = {
      type = "group",
      name = "Eska Quest Tracker",
      childGroups = "tree",
      args = {
        addonInfo = {
          type = "description",
          name = "|cffffd800Addon Info",
          order = 10,
          fontSize = "large",
        },
        addonVersion = {
          type = "description",
          name = CreateRowString("Version", _EQT_VERSION, "0094ff"),
          order = 11,
          fontSize = "medium",
        },
        addonStage = {
          type = "description",
          name = CreateRowString("Stage", _EQT_STAGE, "0094ff", nil, 13),
          order = 12,
          fontSize = "medium",
        },
        slashCommands = {
          type = "description",
          name = "\n\n|cffffd800Slash Commands",
          order = 20,
          fontSize = "large",
        },
        slashOpenOption = {
          type = "description",
          name = "|cffff6a00/eqt|r "..CreateRowString("[open][config][option]", "- open the options", "00ffff", nil, 28),
          order = 21,
        },
        slashShowObjectiveTracker = {
          type = "description",
          name = "|cffff6a00/eqt|r "..CreateRowString("show", "- show the objective tracker", "00ffff", nil, 40),
          order = 22,
        },
        slashHideObjectiveTracker = {
          type = "description",
          name = "|cffff6a00/eqt|r "..CreateRowString("hide", "- hide the objective tracker", "00ffff", nil, 42),
          order = 23,
        },
        slashPrintPLoopVersion = {
          type = "description",
          name = "|cffff6a00/eqt|r "..CreateRowString("ploop", "- print the PLoop version", "00ffff", nil, 40),
          order = 24,
        },
        slashPrintScorpioVersion = {
          type = "description",
          name = "|cffff6a00/eqt|r "..CreateRowString("scorpio", "- print the Scorpio version", "00ffff", nil, 39),
          order = 25,
        },
      dependencies = {
          type = "description",
          name = "\n\n" .."|cffff0000Dependencies|r",
          fontSize = "large",
          order = 30,
          width = "full"
        },

        ploop = {
          type = "description",
          fontSize = "medium",
          order = 31,
          name = "\n".. string.format("----- |cff0094ffPLoop|r   |cff00ff00v%d|r", _PLOOP_VERSION)
        },
        scorpio = {
          type = "description",
          fontSize = "medium",
          order = 32,
          name = string.format("----- |cffff6a00Scorpio|r |cff00ff00v%d|r", _SCORPIO_VERSION)
        }
      }
    }
  }
}

Category = _Settings.args.EQT.args -- @TODO Remove this line
_Categories = _Settings.args.EQT.args


-- Tracker Category

-- ========================================================================== --
-- == TRACKER CATEGORY
-- ========================================================================== --
_Categories.Tracker = {
  type = "group",
  name = "Tracker",
  order = 1,
  args = {
      lock = {
        type = "toggle",
        name = "Lock",
        order = 1,
        get = function() return ObjectiveTrackerFrame.locked end,
        set = function(_, locked) ObjectiveTrackerFrame.locked = locked end
      },
      show = {
        type = "execute",
        name = "Show/Hide",
        order = 2,
        func = function()
          if _Addon.ObjectiveTrackerFrame:IsShown() then
            _Addon.ObjectiveTrackerFrame:Hide()
          else
            _Addon.ObjectiveTrackerFrame:Show()
          end
        end,
      },
      size = {
        type = "group",
        name = "Size",
        order = 3,
        inline = true,
        args = {
          width = {
            type = "range",
            name = "Width",
            order = 1,
            step = 1,
            min = 200,
            max = 340,
            get = function() return ObjectiveTrackerFrame.width end,
            set = function(_, width) ObjectiveTrackerFrame.width = width end,
          },
          height = {
            type = "range",
            name = "Height",
            order = 2,
            step = 1,
            min = 64,
            max = 1024,
            get = function() return ObjectiveTrackerFrame.height end,
            set = function(_, height) ObjectiveTrackerFrame.height = height end,
          }
        }
      }
    }
  }
-- ========================================================================== --

function OnLoad(self)
  --AceConfig:RegisterOptionsTable("EskaQuestTracker", settings)
end

function OnEnable(self)
  --self:RegisterEvent("EvtTest", "Callback")
  _AceConfig:RegisterOptionsTable("EskaQuestTracker", _Settings)
  -- self:Open()
end

function OnDisable(self)

end

__SlashCmd__ "eqt" "config" "- open the options |cffff0000Work in progress|r"
function Open(self)
  if not f then
      f = _AceGUI:Create("Frame")
  end
  _AceConfigDialog:Open("EskaQuestTracker", f)
end
